Struct Cr
#[repr(transparent)]pub struct Cr(pub u32);Expand description
GFXTIM configuration register.
Tuple Fields
0: u32Implementations
impl Cr
impl Cr
pub const fn set_tes(&mut self, val: Tes)
pub const fn set_tes(&mut self, val: Tes)
tearing source This field selects the tearing-effect source.
pub const fn tepol(&self) -> bool
pub const fn tepol(&self) -> bool
tearing–effect polarity This bit selects the tearing-effect polarity.
pub const fn set_tepol(&mut self, val: bool)
pub const fn set_tepol(&mut self, val: bool)
tearing–effect polarity This bit selects the tearing-effect polarity.
pub const fn syncs(&self) -> Syncs
pub const fn syncs(&self) -> Syncs
synchronization source This field selects the synchronization signals (HSYNC and VSYNC) sources.
pub const fn set_syncs(&mut self, val: Syncs)
pub const fn set_syncs(&mut self, val: Syncs)
synchronization source This field selects the synchronization signals (HSYNC and VSYNC) sources.
pub const fn fccoe(&self) -> bool
pub const fn fccoe(&self) -> bool
frame-clock calibration output enable This bit enables the frame-clock output.
pub const fn set_fccoe(&mut self, val: bool)
pub const fn set_fccoe(&mut self, val: bool)
frame-clock calibration output enable This bit enables the frame-clock output.