stm32-metapac

Crates

git

Versions

stm32u5f9zi

Flavors

Ier

Struct Ier 

#[repr(transparent)]
pub struct Ier(pub u32);
GFXTIM interrupt enable register.

Tuple Fields

0: u32

Implementations



impl Ier

pub const fn afcoie(&self) -> bool

absolute frame counter overflow interrupt enable This bit enables the absolute frame counter overflow interrupt generation.

pub const fn set_afcoie(&mut self, val: bool)

absolute frame counter overflow interrupt enable This bit enables the absolute frame counter overflow interrupt generation.

pub const fn alcoie(&self) -> bool

absolute line counter overflow interrupt enable This bit enables the absolute line counter overflow interrupt generation.

pub const fn set_alcoie(&mut self, val: bool)

absolute line counter overflow interrupt enable This bit enables the absolute line counter overflow interrupt generation.

pub const fn teie(&self) -> bool

tearing-effect interrupt enable This bit enables the Tearing Effect interrupt generation.

pub const fn set_teie(&mut self, val: bool)

tearing-effect interrupt enable This bit enables the Tearing Effect interrupt generation.

pub const fn afcc1ie(&self) -> bool

absolute frame counter compare 1 interrupt enable This bit enables the absolute frame counter compare interrupt generation.

pub const fn set_afcc1ie(&mut self, val: bool)

absolute frame counter compare 1 interrupt enable This bit enables the absolute frame counter compare interrupt generation.

pub const fn alcc1ie(&self) -> bool

absolute line counter compare 1 interrupt enable This bit enables the absolute line counter compare 1 interrupt generation.

pub const fn set_alcc1ie(&mut self, val: bool)

absolute line counter compare 1 interrupt enable This bit enables the absolute line counter compare 1 interrupt generation.

pub const fn alcc2ie(&self) -> bool

absolute line counter compare 2 interrupt enable This bit enables the absolute line counter compare 2 interrupt generation.

pub const fn set_alcc2ie(&mut self, val: bool)

absolute line counter compare 2 interrupt enable This bit enables the absolute line counter compare 2 interrupt generation.

pub const fn rfc1rie(&self) -> bool

relative frame counter 1 reload interrupt enable This bit enables the relative frame counter 1 reload interrupt generation.

pub const fn set_rfc1rie(&mut self, val: bool)

relative frame counter 1 reload interrupt enable This bit enables the relative frame counter 1 reload interrupt generation.

pub const fn rfc2rie(&self) -> bool

relative frame counter 2 reload interrupt enable This bit enables the relative frame counter 2 reload interrupt generation.

pub const fn set_rfc2rie(&mut self, val: bool)

relative frame counter 2 reload interrupt enable This bit enables the relative frame counter 2 reload interrupt generation.

pub const fn ev1ie(&self) -> bool

event 1 interrupt enable This bit enables the complex event 1 interrupt generation.

pub const fn set_ev1ie(&mut self, val: bool)

event 1 interrupt enable This bit enables the complex event 1 interrupt generation.

pub const fn ev2ie(&self) -> bool

event 2 interrupt enable This bit enables the complex event 2 interrupt generation.

pub const fn set_ev2ie(&mut self, val: bool)

event 2 interrupt enable This bit enables the complex event 2 interrupt generation.

pub const fn ev3ie(&self) -> bool

event 3 interrupt enable This bit enables the complex event 3 interrupt generation.

pub const fn set_ev3ie(&mut self, val: bool)

event 3 interrupt enable This bit enables the complex event 3 interrupt generation.

pub const fn ev4ie(&self) -> bool

event 4 interrupt enable This bit enables the complex event 4 interrupt generation.

pub const fn set_ev4ie(&mut self, val: bool)

event 4 interrupt enable This bit enables the complex event 4 interrupt generation.

pub const fn wdgaie(&self) -> bool

watchdog alarm interrupt enable This bit enables the watchdog alarm interrupt generation.

pub const fn set_wdgaie(&mut self, val: bool)

watchdog alarm interrupt enable This bit enables the watchdog alarm interrupt generation.

pub const fn wdgpie(&self) -> bool

watchdog pre-alarm interrupt enable This bit enables the watchdog pre-alarm interrupt generation.

pub const fn set_wdgpie(&mut self, val: bool)

watchdog pre-alarm interrupt enable This bit enables the watchdog pre-alarm interrupt generation.