stm32-metapac

Crates

git

Versions

stm32u5f9zi

Flavors

Tcr

Struct Tcr 

#[repr(transparent)]
pub struct Tcr(pub u32);
GFXTIM timers configuration register.

Tuple Fields

0: u32

Implementations



impl Tcr

pub const fn afcen(&self) -> bool

absolute frame counter enable This bit enables the absolute frame counter.

pub const fn set_afcen(&mut self, val: bool)

absolute frame counter enable This bit enables the absolute frame counter.

pub const fn fafcr(&self) -> bool

force absolute frame counter reset This bit forces the reset of the absolute frame counter.

pub const fn set_fafcr(&mut self, val: bool)

force absolute frame counter reset This bit forces the reset of the absolute frame counter.

pub const fn alcen(&self) -> bool

absolute line counter enable This bit enables the absolute line counter.

pub const fn set_alcen(&mut self, val: bool)

absolute line counter enable This bit enables the absolute line counter.

pub const fn falcr(&self) -> bool

force absolute line counter reset This bit forces the reset of the absolute line counter.

pub const fn set_falcr(&mut self, val: bool)

force absolute line counter reset This bit forces the reset of the absolute line counter.

pub const fn rfc1en(&self) -> bool

relative frame counter 1 enable This bit enables the relative frame counter 1.

pub const fn set_rfc1en(&mut self, val: bool)

relative frame counter 1 enable This bit enables the relative frame counter 1.

pub const fn rfc1cm(&self) -> bool

relative frame counter 1 continuous mode This bit enables the continuous mode of the relative frame counter 1.

pub const fn set_rfc1cm(&mut self, val: bool)

relative frame counter 1 continuous mode This bit enables the continuous mode of the relative frame counter 1.

pub const fn frfc1r(&self) -> bool

force relative frame counter 1 reload This bit forces the reload of the relative frame counter 1.

pub const fn set_frfc1r(&mut self, val: bool)

force relative frame counter 1 reload This bit forces the reload of the relative frame counter 1.

pub const fn rfc2en(&self) -> bool

relative frame counter 2 enable This bit enables the relative frame counter 2.

pub const fn set_rfc2en(&mut self, val: bool)

relative frame counter 2 enable This bit enables the relative frame counter 2.

pub const fn rfc2cm(&self) -> bool

relative frame counter 2 continuous mode This bit enables the continuous mode of the relative frame counter 2.

pub const fn set_rfc2cm(&mut self, val: bool)

relative frame counter 2 continuous mode This bit enables the continuous mode of the relative frame counter 2.

pub const fn frfc2r(&self) -> bool

force relative frame counter 2 reload This bit forces the reload of the relative frame counter 2.

pub const fn set_frfc2r(&mut self, val: bool)

force relative frame counter 2 reload This bit forces the reload of the relative frame counter 2.