Struct Tdr
#[repr(transparent)]pub struct Tdr(pub u32);Expand description
GFXTIM timers disable register.
Tuple Fields
0: u32Implementations
impl Tdr
impl Tdr
pub const fn afcdis(&self) -> bool
pub const fn afcdis(&self) -> bool
absolute frame counter disable This bit disables the absolute frame counter.
pub const fn set_afcdis(&mut self, val: bool)
pub const fn set_afcdis(&mut self, val: bool)
absolute frame counter disable This bit disables the absolute frame counter.
pub const fn alcdis(&self) -> bool
pub const fn alcdis(&self) -> bool
absolute line counter disable This bit disables the absolute line counter.
pub const fn set_alcdis(&mut self, val: bool)
pub const fn set_alcdis(&mut self, val: bool)
absolute line counter disable This bit disables the absolute line counter.
pub const fn rfc1dis(&self) -> bool
pub const fn rfc1dis(&self) -> bool
relative frame counter 1 disable This bit disables the relative frame counter 1.
pub const fn set_rfc1dis(&mut self, val: bool)
pub const fn set_rfc1dis(&mut self, val: bool)
relative frame counter 1 disable This bit disables the relative frame counter 1.
pub const fn rfc2dis(&self) -> bool
pub const fn rfc2dis(&self) -> bool
relative frame counter 2 disable This bit disables the relative frame counter 2.
pub const fn set_rfc2dis(&mut self, val: bool)
pub const fn set_rfc2dis(&mut self, val: bool)
relative frame counter 2 disable This bit disables the relative frame counter 2.