Struct Tsr
#[repr(transparent)]pub struct Tsr(pub u32);Expand description
GFXTIM timers status register.
Tuple Fields
0: u32Implementations
impl Tsr
impl Tsr
pub const fn afcs(&self) -> bool
pub const fn afcs(&self) -> bool
absolute frame counter status This bit returns the status of the absolute frame counter.
pub const fn set_afcs(&mut self, val: bool)
pub const fn set_afcs(&mut self, val: bool)
absolute frame counter status This bit returns the status of the absolute frame counter.
pub const fn alcs(&self) -> bool
pub const fn alcs(&self) -> bool
absolute line counter status This bit returns the status of the absolute line counter.
pub const fn set_alcs(&mut self, val: bool)
pub const fn set_alcs(&mut self, val: bool)
absolute line counter status This bit returns the status of the absolute line counter.
pub const fn rfc1s(&self) -> bool
pub const fn rfc1s(&self) -> bool
relative frame counter 1 status This bit returns the status of the relative frame counter 1.
pub const fn set_rfc1s(&mut self, val: bool)
pub const fn set_rfc1s(&mut self, val: bool)
relative frame counter 1 status This bit returns the status of the relative frame counter 1.