Struct Wdgtcr
#[repr(transparent)]pub struct Wdgtcr(pub u32);Expand description
GFXTIM watchdog timer configuration register.
Tuple Fields
0: u32Implementations
impl Wdgtcr
impl Wdgtcr
pub const fn set_wdgdis(&mut self, val: bool)
pub const fn set_wdgdis(&mut self, val: bool)
watchdog disable This bit disables the graphic watchdog.
pub const fn wdgs(&self) -> bool
pub const fn wdgs(&self) -> bool
watchdog status This bit returns the status of the graphic watchdog.
pub const fn set_wdgs(&mut self, val: bool)
pub const fn set_wdgs(&mut self, val: bool)
watchdog status This bit returns the status of the graphic watchdog.
pub const fn wdghrc(&self) -> Wdghrc
pub const fn wdghrc(&self) -> Wdghrc
watchdog hardware reload configuration This field configures the watchdog hardware reload.
pub const fn set_wdghrc(&mut self, val: Wdghrc)
pub const fn set_wdghrc(&mut self, val: Wdghrc)
watchdog hardware reload configuration This field configures the watchdog hardware reload.
pub const fn wdgcs(&self) -> Wdgcs
pub const fn wdgcs(&self) -> Wdgcs
watchdog clock source This field selects the watchdog clock source. others: reserved.
pub const fn set_wdgcs(&mut self, val: Wdgcs)
pub const fn set_wdgcs(&mut self, val: Wdgcs)
watchdog clock source This field selects the watchdog clock source. others: reserved.